Struct LangInner
Source pub struct LangInner<N: NodeTypes> { }
Generic language implementation parameterized by node types.
This struct provides a single implementation of LangImpl that works with
any NodeTypes implementation (static or dynamic).
Formats the value using the given formatter.
Read more
Parse source code into a tree-sitter tree.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.